@@ -4,14 +4,15 @@ from __future__ import annotations
 
 from weakref import WeakKeyDictionary
 
-from pywayland.server import Display, Signal
 from pywayland.protocol.wayland import WlSeat
+from pywayland.server import Display, Signal
+
+from wlroots import Ptr, PtrHasData, ffi, lib
 
-from wlroots import ffi, PtrHasData, lib, Ptr
 from .data_device_manager import Drag
-from .input_device import ButtonState, InputDevice
-from .keyboard import Keyboard, KeyboardModifiers, KeyboardKeyEvent
-from .pointer import AxisSource, AxisOrientation
+from .input_device import ButtonState
+from .keyboard import Keyboard, KeyboardKeyEvent, KeyboardModifiers
+from .pointer import AxisOrientation, AxisSource
 from .surface import Surface
 
 _weakkeydict: WeakKeyDictionary = WeakKeyDictionary()
@@ -115,9 +116,11 @@ class Seat(PtrHasData):
         return SeatKeyboardState(keyboard_state_ptr)
 
     @property
-    def keyboard(self) -> Keyboard:
-        """Get the keyboard associated with this seat"""
+    def keyboard(self) -> Keyboard | None:
+        """Get the active keyboard for the seat."""
         keyboard_ptr = lib.wlr_seat_get_keyboard(self._ptr)
+        if keyboard_ptr == ffi.NULL:
+            return None
         return Keyboard(keyboard_ptr)
 
     def destroy(self) -> None:
@@ -226,13 +229,13 @@ class Seat(PtrHasData):
         """Whether or not the pointer has a grab other than the default grab"""
         lib.wlr_seat_pointer_has_grab(self._ptr)
 
-    def set_keyboard(self, input_device: InputDevice) -> None:
+    def set_keyboard(self, keyboard: Keyboard) -> None:
         """Set this keyboard as the active keyboard for the seat
 
-        :param input_device:
-            The input device associated to the keyboard to set
+        :param keyboard:
+            The keyboard to set as active.
         """
-        lib.wlr_seat_set_keyboard(self._ptr, input_device._ptr)
+        lib.wlr_seat_set_keyboard(self._ptr, keyboard._ptr)
 
     def grab(self) -> KeyboardGrab:
         """Start a grab of the keyboard of this seat"""
